@@ -1,4 +1,4 @@
-package cppAdaptive2 v2.0.2;
+package cppAdaptive2 v3.0.0;
 
 use strict;
 use warnings;
@@ -36,8 +36,16 @@ AV* _update(char* obsVector, char* futVector, char* betaVector, int n_observed)
     return av;
 }
 CPP
-    inc               => '-I../../../../src',
-    ccflags           => '-std=c++11',
+
+    # without omp
+    # inc       => '-I../../../../src',
+    # ccflags   => '-std=c++11',
+
+    # with omp
+    inc       => '-I../../../../src',
+    ccflags   => '-std=c++11 -fopenmp',
+    lddlflags => '-shared -O2 -fstack-protector-strong -fopenmp',
+
     clean_after_build => 0,
     clean_build_area  => 0,
 );
